@@ -17,26 +17,25 @@ Y <- rbinom(n, 1, plogis(W$W1 + W$W2*A))
 
 ## ------------------------------------------------------------------------
 glm_fit_uni <- drtmle(W = W, A = A, Y = Y, family = binomial(),
-                      glm_g = "W1 + W2", glm_Q = "W1 + W2*A", 
+                      glm_g = "W1 + W2", glm_Q = "W1 + W2*A",
                       glm_gr = "Qn", glm_Qr = "gn", stratify = FALSE)
 glm_fit_uni
 
 glm_fit_biv <- drtmle(W = W, A = A, Y = Y, family = binomial(),
-                      glm_g = "W1 + W2", glm_Q = "W1 + W2*A", 
+                      glm_g = "W1 + W2", glm_Q = "W1 + W2*A",
                       glm_gr = "Qn", glm_Qr = "gn", stratify = FALSE,
                       reduction = "bivariate")
 glm_fit_biv
 
-
 ## ---- echo = FALSE, message = FALSE--------------------------------------
 library(SuperLearner)
 
 ## ---- message = FALSE, cache = TRUE--------------------------------------
 sl_fit <- drtmle(W = W, A = A, Y = Y, family = binomial(),
-                 SL_g = c("SL.glm", "SL.step.interaction","SL.mean"), 
-                 SL_Q = c("SL.glm", "SL.step.interaction","SL.mean"), 
+                 SL_g = c("SL.glm", "SL.step.interaction","SL.mean"),
+                 SL_Q = c("SL.glm", "SL.step.interaction","SL.mean"),
                  SL_gr = c("SL.glm", "SL.gam", "SL.mean"),
-                 SL_Qr = c("SL.glm", "SL.gam", "SL.mean"), 
+                 SL_Qr = c("SL.glm", "SL.gam", "SL.mean"),
                  stratify = FALSE)
 sl_fit
 
@@ -45,10 +44,10 @@ SL.npreg
 
 ## ---- cache = TRUE, message = FALSE--------------------------------------
 npreg_fit <- drtmle(W = W, A = A, Y = Y, family = binomial(),
-                    SL_g = "SL.npreg", SL_Q = "SL.npreg", 
+                    SL_g = "SL.npreg", SL_Q = "SL.npreg",
                     SL_gr = "SL.npreg", SL_Qr = "SL.npreg",
                     stratify = TRUE)
-npreg_fit                    
+npreg_fit
 
 ## ------------------------------------------------------------------------
 ci(npreg_fit)
@@ -66,7 +65,7 @@ ci(npreg_fit, contrast = riskRatio)
 ## ------------------------------------------------------------------------
 logitMean <- list(f = function(eff){ qlogis(eff) },
                   f_inv = function(eff){ plogis(eff) },
-                  h = function(est){ est[1] }, 
+                  h = function(est){ est[1] },
                   fh_grad = function(est){ c(1/(est[1] - est[1]^2), 0) })
 ci(npreg_fit, contrast = logitMean)
 
@@ -88,7 +87,7 @@ Y[DeltaY == 0] <- NA
 
 ## ---- cache = TRUE-------------------------------------------------------
 glm_fit_wNAs <- drtmle(W = W, A = A, Y = Y, stratify = FALSE,
-                       glm_g = list(DeltaA = "W1 + W2", A = "W1 + W2", 
+                       glm_g = list(DeltaA = "W1 + W2", A = "W1 + W2",
                                     DeltaY = "W1 + W2 + A"),
                        glm_Q = "W1 + W2*A", glm_Qr = "gn",
                        glm_gr = "Qn", family = binomial())
@@ -96,11 +95,11 @@ glm_fit_wNAs
 
 ## ---- cache = TRUE-------------------------------------------------------
 mixed_fit_wNAs <- drtmle(W = W, A = A, Y = Y, stratify = FALSE,
-                         SL_g = list(DeltaA = "SL.glm", A = "SL.npreg", 
+                         SL_g = list(DeltaA = "SL.glm", A = "SL.npreg",
                          DeltaY = c("SL.glm", "SL.mean", "SL.gam")),
                          glm_Q = "W1 + W2*A", glm_Qr = "gn",
                          glm_gr = "Qn", family = binomial())
-mixed_fit_wNAs                         
+mixed_fit_wNAs
 
 ## ---- echo = FALSE, message = FALSE--------------------------------------
 library(drtmle)
@@ -124,9 +123,9 @@ Y <- rbinom(n, 1, plogis(W$W1 + W$W2*A))
 ## ---- cache = TRUE, message = FALSE--------------------------------------
 glm_fit_multiA <- drtmle(W = W, A = A, Y = Y, stratify = FALSE,
                          glm_g = "W1 + W2", glm_Q = "W1 + W2*A",
-                         glm_gr = "Qn", glm_Qr = "gn", 
+                         glm_gr = "Qn", glm_Qr = "gn",
                          family = binomial(), a_0 = c(0,1,2))
-glm_fit_multiA                         
+glm_fit_multiA
 
 ## ---- cache = TRUE-------------------------------------------------------
 ci(glm_fit_multiA)
@@ -154,32 +153,33 @@ ci(glm_fit_multiA, contrast = riskRatio_2v0)
 
 ## ---- cache = TRUE-------------------------------------------------------
 cv_sl_fit <- drtmle(W = W, A = A, Y = Y, family = binomial(),
-                 SL_g = c("SL.glm", "SL.glm.interaction", "SL.gam"), 
-                 SL_Q = c("SL.glm", "SL.glm.interaction", "SL.gam"), 
-                 SL_gr = c("SL.glm", "SL.gam", "SL.mean"),
-                 SL_Qr = c("SL.glm", "SL.gam", "SL.mean"), 
-                 stratify = FALSE, cvFolds = 2, a_0 = c(0,1,2))
+                    SL_g = c("SL.glm", "SL.glm.interaction", "SL.gam"),
+                    SL_Q = c("SL.glm", "SL.glm.interaction", "SL.gam"),
+                    SL_gr = c("SL.glm", "SL.gam", "SL.mean"),
+                    SL_Qr = c("SL.glm", "SL.gam", "SL.mean"),
+                    stratify = FALSE, cvFolds = 2, a_0 = c(0, 1, 2))
 cv_sl_fit
 
 ## ---- cache = TRUE, message = FALSE--------------------------------------
-library(doParallel)
-workers <- makeCluster(2, type="SOCK")
-registerDoParallel(workers)
+library(future.batchtools)
+library(parallel)
+cl <- makeCluster(2, type = "SOCK")
+plan(cluster, workers = cl)
+clusterEvalQ(cl, library("SuperLearner"))
 pcv_sl_fit <- drtmle(W = W, A = A, Y = Y, family = binomial(),
-                 SL_g = c("SL.glm", "SL.glm.interaction","SL.gam"), 
-                 SL_Q = c("SL.glm", "SL.glm.interaction","SL.gam"), 
-                 SL_gr = c("SL.glm", "SL.gam", "SL.mean"),
-                 SL_Qr = c("SL.glm", "SL.gam", "SL.mean"), 
-                 stratify = FALSE, a_0 = c(0,1,2), 
-                 cvFolds = 2, parallel = TRUE)
-stopCluster(workers)
+                     SL_g = c("SL.glm", "SL.glm.interaction","SL.gam"),
+                     SL_Q = c("SL.glm", "SL.glm.interaction","SL.gam"),
+                     SL_gr = c("SL.glm", "SL.gam", "SL.mean"),
+                     SL_Qr = c("SL.glm", "SL.gam", "SL.mean"),
+                     stratify = FALSE, a_0 = c(0,1,2),
+                     cvFolds = 2, parallel = TRUE)
 pcv_sl_fit
 
 ## ---- cache = TRUE-------------------------------------------------------
 npreg_iptw_multiA <- adaptive_iptw(W = W, A = A, Y = Y, stratify = FALSE,
-                                   SL_g = "SL.npreg", SL_Qr = "SL.npreg", 
+                                   SL_g = "SL.npreg", SL_Qr = "SL.npreg",
                                    family = binomial(), a_0 = c(0,1,2))
-npreg_iptw_multiA                                   
+npreg_iptw_multiA
 
 ## ------------------------------------------------------------------------
 sessionInfo()
